@@ -119,9 +119,15 @@ class Text:
                         case "27": tn = not tn
                         case "28": vm = not vm
                         case "29": hm = not hm
-                        case "30": bg, bg_c = not bg, char.args
-                        case "31": fg, fg_c = not fg, char.args
-                        case "32": ls, ls_c = not ls, char.args
+                        case "30":
+                            try: bg, bg_c = not bg, char.args
+                            except: bg = False
+                        case "31":
+                            try: fg, fg_c = not fg, char.args
+                            except: bg = False
+                        case "32":
+                            try: ls, ls_c = not ls, char.args
+                            except: bg = False
                     format = r
                 else:
                     styles = []
@@ -271,12 +277,13 @@ class Text:
 
 if __name__ == "__main__":
     used, total = len(CHARS), 100 + 26*10 + 26*100 # (0-99)+(A0-A9)+(A00-Z99)
-    from pyimager.test import *
+    from pyimager.test import new_img
     img = new_img()
     drawn = 0
     for i in CHARS:
-        c = Text(i).text.chain[0]
-        r = draw_char(img, c, [[0,0], [1,0], [0,1], [1,1]], help=True)
-        print(c, r)
-        if r: drawn += 1
+        try:
+            c = Text(f"^{i}^")
+            r = draw_char(img, c, [[0,0], [1,0], [0,1], [1,1]], errors=True)
+            drawn += 1
+        except UnassignedChar as e: print(e)
     print(f"{used:0>4}/{total} => {used/total:.2%} used\n{drawn:0>4}/{used} => {drawn/used:.2%} drawn")
\ No newline at end of file
